@@ -25,9 +25,3 @@ def setup_logger(name):
     return logger
 
 LOGGER = setup_logger('root')
-
-TEST_LOGGER = setup_logger('test')
-
-FH = logging.FileHandler('test.log')
-
-TEST_LOGGER.addHandler(FH)
